Documentation
¶
Overview ¶
Package servicegraph defines the core model for the servicegraph service.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Attributes ¶
Attributes contain a set of annotations for an edge.
type Dynamic ¶
Dynamic represents a service graph generated on the fly.
type Edge ¶
type Edge struct {
Source string `json:"source"`
Target string `json:"target"`
Labels Attributes `json:"labels"`
}
Edge represents an edge in a dynamic service graph.
type SerializeFn ¶
SerializeFn provides a mechanism for writing out the service graph.
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
demosvc
command
|
|
|
server
command
|
|
|
Package dot provides serialization utilities for a servicegraph using the dot format.
|
Package dot provides serialization utilities for a servicegraph using the dot format. |
|
Package promgen generates service graphs from a prometheus backend.
|
Package promgen generates service graphs from a prometheus backend. |
Click to show internal directories.
Click to hide internal directories.